<?php
/**
 * Expired Booking email
 *
 * @author  MakeWebBetter
 * @package MWB_Bookings_For_WooCommerce
 * @subpackage MWB_Bookings_For_WooCommerce/admin/templates/emails
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

do_action( 'woocommerce_email_header', $email_heading, $email ); ?>

<?php /* translators: $1: customer's billing first name and last name */ ?>
<p><?php printf( esc_html__( 'Booking belonging to %1$s has been expired. Their booking\'s details are as follows:', 'mwb-bookings-for-woocommerce' ), esc_html( $order->get_formatted_billing_full_name() ) ); ?></p>

<table class="td" cellspacing="0" cellpadding="6" style="width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;" border="1">
	<thead>
		<tr>
			<th class="td" scope="col" style="text-align:left;"><?php esc_html_e( 'Booking', 'mwb-bookings-for-woocommerce' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'Price', 'table headings in notification email', 'mwb-bookings-for-woocommerce' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'Start Date', 'table heading', 'mwb-bookings-for-woocommerce' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'End Date', 'table heading', 'mwb-bookings-for-woocommerce' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td class="td" width="1%" style="text-align:left; vertical-align:middle;">
				<a href="<?php echo esc_url( get_option( 'siteurl' ) . '/my-account/all_bookings/?booking_id=' . $booking_id ); ?>">#<?php echo esc_html( $booking_id ); ?></a>
			</td>
			<td class="td" style="text-align:left; vertical-align:middle;">
				<?php $meta = $order->get_meta( 'mwb_meta_data' ); ?>
				<?php echo wp_kses_post( get_woocommerce_currency_symbol() . ' ' . $booking_meta['total_cost'] ); ?>
			</td>
			<td class="td" style="text-align:left; vertical-align:middle;">
				<?php
				echo esc_html( gmdate( 'Y-m-d h:i:s a', $booking_meta['start_timestamp'] ) );
				?>
			</td>
			<td class="td" style="text-align:left; vertical-align:middle;">
				<?php
				echo esc_html( gmdate( 'Y-m-d h:i:s a', $booking_meta['end_timestamp'] ) );
				?>
			</td>
		</tr>
	</tbody>
</table>
<?php $order_data = $order->get_data(); ?>
<section class="woocommerce-customer-details">
	<h2 class="woocommerce-column__title"><?php esc_html_e( 'Billing address', 'mwb-bookings-for-woocommerce' ); ?></h2>
	<address>
		<?php echo esc_html( $order_data['billing']['first_name'] ); ?><br><?php echo esc_html( $order_data['billing']['last_name'] ); ?><br><?php echo esc_html( $order_data['billing']['address_1'] ); ?><br><?php echo esc_html( $order_data['billing']['address_2'] ); ?><br><?php echo esc_html( $order_data['billing']['city'] ); ?><?php echo esc_html( $order_data['billing']['state'] ); ?><br><?php echo esc_html( $order_data['billing']['postcode'] ); ?><br><?php echo esc_html( $order_data['billing']['country'] ); ?>
			<p class="woocommerce-customer-details--phone"><?php echo esc_html( $order_data['billing']['phone'] ); ?></p>	
			<p class="woocommerce-customer-details--email"><?php echo esc_html( $order_data['billing']['email'] ); ?></p>
	</address>
</section>
<?php

do_action( 'mwb_booking_add_other_details', $order, $sent_to_admin, $plain_text, $email, $booking_meta );

/**
 * Show user-defined additional content - this is set in each email's settings.
 */
if ( $additional_content ) {
	echo wp_kses_post( wpautop( wptexturize( $additional_content ) ) );
}

do_action( 'woocommerce_email_footer', $email );
